@@ -9,6 +9,8 @@ class SyntaxHighlightingSettings:
         self.linenos = True
         self.css_class = "highlight"
         self.linenos_class = "linenos"
+        self.wrap = True
+        self.wrap_class = "highlight"
 
     @staticmethod
     def from_settings(pelican: Pelican) -> SyntaxHighlightingSettings:
@@ -22,5 +24,7 @@ class SyntaxHighlightingSettings:
         obj.linenos = settings.get("linenos", obj.linenos)
         obj.css_class = settings.get("css_class", obj.css_class)
         obj.linenos_class = settings.get("linenos_class", obj.linenos_class)
+        obj.wrap = settings.get("wrap", obj.wrap)
+        obj.wrap_class = settings.get("wrap_class", obj.wrap_class)
 
         return obj
